@@ -10,27 +10,38 @@ import requests
 from jarvis.db.jsonutils import loadjson
 
 
-def datasets(dataset=''):
+def datasets(dataset=""):
     """Get collection of dataset names and URLs."""
-    if dataset == 'dft_2d':
+    if dataset == "dft_2d":
         url = "https://ndownloader.figshare.com/files/22471019"
-        js_tag = 'jdft_2d-4-26-2020.json'
-        print('Obtaining 2D dataset ...')
-    elif dataset == 'dft_3d':
+        js_tag = "jdft_2d-4-26-2020.json"
+        print("Obtaining 2D dataset ...")
+    elif dataset == "dft_3d":
         url = "https://ndownloader.figshare.com/files/22471022"
-        js_tag = 'jdft_3d-4-26-2020.json'
-        print('Obtaining 3D dataset ...')
-
-    elif dataset == 'cfid_3d':
+        js_tag = "jdft_3d-4-26-2020.json"
+        print("Obtaining 3D dataset ...")
+    elif dataset == "cfid_3d":
         url = "https://ndownloader.figshare.com/files/22470818"
-        js_tag = 'jml_3d-4-26-2020.json'
-        print('Obtaining 3D CFID dataset ...')
+        js_tag = "jml_3d-4-26-2020.json"
+        print("Obtaining JARVIS-3D CFID dataset 37k...")
+    elif dataset == "mp_3d":
+        url = "https://ndownloader.figshare.com/files/24979850"
+        js_tag = "CFID_mp_desc_data_84k.json"
+        print("Obtaining Materials Project-3D CFID dataset 84k...")
+    elif dataset == "oqmd_3d":
+        url = "https://ndownloader.figshare.com/files/24981170"
+        js_tag = "CFID_OQMD_460k.json"
+        print("Obtaining OQMD-3D CFID dataset 460k...")
+    elif dataset == "qm9":
+        url = "https://ndownloader.figshare.com/files/25159592"
+        js_tag = "qm9_data_cfid.json"
+        print("Obtaining QM9-molecule CFID dataset 134k...")
     else:
-        ValueError('Dataset doesnt exist', dataset)
+        ValueError("Dataset doesnt exist", dataset)
     return url, js_tag
 
 
-def data(dataset='dft_2d'):
+def data(dataset="dft_2d"):
     """Provide main function to download datasets."""
     url, js_tag = datasets(dataset)
     path = str(os.path.join(os.path.dirname(__file__), js_tag))
@@ -41,7 +52,7 @@ def data(dataset='dft_2d'):
         f.write(r.content)
         f.close()
 
-        with zipfile.ZipFile(zfile, 'r') as zipObj:
+        with zipfile.ZipFile(zfile, "r") as zipObj:
             # zipObj.extract(path)
             zipObj.extractall(os.path.join(os.path.dirname(__file__)))
         os.remove(zfile)
@@ -49,6 +60,14 @@ def data(dataset='dft_2d'):
     return data
 
 
+def get_jid_data(jid="JVASP-667", dataset="dft_2d"):
+    """Get info for a jid and dataset."""
+    d = data(dataset)
+    for i in d:
+        if i["jid"] == jid:
+            return i
+
+
 def get_ff_eneleast():
     """Get JARVIS-FF related data."""
     jff1 = str(os.path.join(os.path.dirname(__file__), "jff1.json"))
